# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:versionidentifier) do
  include EasyType

  defaultto :absent

  desc <<-DESC
  The version identifier.

  DESC

  data_type('Optional[String]')
  def insync?(arg, refreshing: false)
    if !refreshing
      return true if resource[:refreshonly].to_s == 'true'

      @called_before = true # We have already told Puppet everything it needs to know.
    elsif @called_before
      return true
    end
    arg = '' if arg.to_s == 'absent'
    requested_value = absent?(should) ? version_in_ear : should
    synced = arg == requested_value
    Puppet.notice "#{path}: #{change_to_s(arg, requested_value)} because of refresh." if refreshing && !synced
    synced
  end

  def change_to_s(arg, should)
    arg = '' if arg.to_s == 'absent'
    requested_value = absent?(should) ? version_in_ear : should
    super(arg, requested_value)
  end

  to_translate_to_resource do |raw_resource|
    raw_resource['versionidentifier']
  end
end

def versionidentifier
  self[:versionidentifier].to_s == 'absent' ? version_in_ear : self[:versionidentifier]
end

private

def absent?(value)
  value.nil? || value.to_s == 'absent'
end

def version_in_ear
  # rubocop:disable Style/RedundantBegin
  begin
    # rubocop:enable Style/RedundantBegin
    # rubocop:disable Security/Open
    @version_in_ear ||= open("| unzip -p #{resource[:localpath]} META-INF/MANIFEST.MF | grep -i WebLogic-Application-Version:").read.split(':')[1].strip
    # rubocop:enable Security/Open
  rescue StandardError
    ''
  end
end
